#GIT_CMT=6225da73c69273e756d083d21bff94f8ff1c9daf
# Copyright(c) 2015, Oracle and/or its affiliates.  All Rights Reserved.
#
#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.

# Python major version.
%{expand: %%define pyver %(python -c 'import sys;print(sys.version[0:3])')}

# Package version
%global package_version 0.1

# Kolla user name and group name (DO NOT CHANGE THESE!)
%global kolla_user      kolla
%global kolla_group     %{kolla_user}


Summary:        OpenStack Kolla CLI
Name:           openstack-kollacli
Version:        %{package_version}
Release:    121.el7
License:        Apache License, Version 2.0
Group:          Applications/System
Url:            https://launchpad.net/kolla
Source0: openstack-kollacli-0.1.tar.bz2
BuildArch:      noarch
BuildRequires:  python                      >= 2.7
BuildRequires:  python-setuptools           >= 0.9.8
BuildRequires:  python-pbr                  >= 1.3.0
Requires:       openstack-kolla-ansible     >= 0.1.0
Requires:       babel                       >= 2.0
Requires:       pexpect                     >= 2.3
Requires:       python-babel                >= 2.0
Requires:       python-cliff                >= 1.13.0
Requires:       python-cliff-tablib         >= 1.1
Requires:       python-jsonpickle           >= 0.9.2
Requires:       python-oslo-i18n            >= 2.5.0
Requires:       python-paramiko             >= 1.15.1
Requires:       python-pbr                  >= 1.6.0
Requires:       python-six                  >= 1.9.0
Requires:       PyYAML                      >= 3.10

Requires:       /usr/bin/ssh-keygen


%description
The KollaCLI simplifies OpenStack Kolla deployments.


%prep
%setup -q -n %{name}-%{version}


%build
# Generate a temporary pkg-info file to make pbr happy
PKGINFO_NAME=$(sed -n -e '/^name/ s/name\s=\s//p' setup.cfg)
PKGINFO_VERSION=$(sed -n -e '/^version/ s/version\s=\s//p' setup.cfg)
cat >PKG-INFO <<__EOF__
Metadata-Version: 1.1
Name: ${PKGINFO_NAME}
Version: ${PKGINFO_VERSION}
__EOF__

# Build the package
%{__python} setup.py build


%install
# Install the package
%{__python} setup.py install --skip-build --root %{buildroot}

# Create the required directory structures
mkdir -m 0755 -p %{buildroot}/%{_sysconfdir}/kolla/kollacli
mkdir -m 0775 -p %{buildroot}/%{_sysconfdir}/kolla/kollacli/ansible
mkdir -m 0750 -p %{buildroot}/%{_datadir}/kolla/kollacli/tools
mkdir -m 0750 -p %{buildroot}/%{_datadir}/kolla/kollacli/ansible

# Create a kolla log directory
mkdir -m 0770 -p %{buildroot}/%{_var}/log/kolla

# Install the required OpenStack Kolla files
cp -r tools/* %{buildroot}/%{_datadir}/kolla/kollacli/tools
cp -r ansible/* %{buildroot}/%{_datadir}/kolla/kollacli/ansible

# Create an empty inventory file
touch %{buildroot}/%{_sysconfdir}/kolla/kollacli/ansible/inventory.json
chmod 0664 %{buildroot}/%{_sysconfdir}/kolla/kollacli/ansible/inventory.json

%clean
rm -rf %{buildroot}


%files
%defattr(-, %{kolla_user}, %{kolla_group})
%attr(-, root, root) %doc LICENSE
%attr(-, root, root) %{python_sitelib}
%attr(755, root, %{kolla_group}) %{_bindir}/kollacli
%attr(550, %{kolla_user}, %{kolla_group}) %dir %{_datadir}/kolla/kollacli/tools
%attr(500, %{kolla_user}, %{kolla_group}) %{_datadir}/kolla/kollacli/tools/passwd*
%attr(550, %{kolla_user}, %{kolla_group}) %{_datadir}/kolla/kollacli/tools/log_*
%attr(550, %{kolla_user}, %{kolla_group}) %{_datadir}/kolla/kollacli/ansible/*.yml
%attr(-, %{kolla_user}, %{kolla_group}) %config(noreplace) %{_sysconfdir}/kolla/kollacli
%attr(2770, %{kolla_user}, %{kolla_group}) %dir %{_var}/log/kolla

%post
setfacl -m d:g:%{kolla_group}:rw %{_var}/log/kolla

if ! test -f ~%{kolla_user}/.ssh/id_rsa
then
    runuser -m -s /bin/bash -c \
        "/usr/bin/ssh-keygen -q -t rsa -N '' -f ~%{kolla_user}/.ssh/id_rsa" \
        %{kolla_user}
fi

if ! test -f %{_sysconfdir}/kolla/kollacli/id_rsa.pub
then
    cp -p ~%{kolla_user}/.ssh/id_rsa.pub %{_sysconfdir}/kolla/kollacli/id_rsa.pub
    chmod 0440 %{_sysconfdir}/kolla/kollacli/id_rsa.pub
fi

/usr/bin/kollacli complete >/etc/bash_completion.d/kollacli 2>/dev/null

# Update the sudoers file
if ! grep -q 'kollacli/tools/passwd_editor' /etc/sudoers.d/%{kolla_user}
then
    sed -i \
        '/^Cmnd_Alias.*KOLLA_CMDS/ s:$:, %{_datadir}/kolla/kollacli/tools/passwd_editor.py:'\
        /etc/sudoers.d/%{kolla_user}
fi

# remove obsolete json_generator script
if test -f %{_datadir}/kolla/kollacli/tools/json_generator.py
then
    rm -f %{_datadir}/kolla/kollacli/tools/json_generator.py
fi

%postun
case "$*" in
    0)
        rm -f /etc/bash_completion.d/kollacli
    ;;
    *)
        ## Nothing for update
    ;;
esac


%changelog
* Fri Dec 11 2015 Steve Noyes <steve.noyes@oracle.com> - 0.1-121.el7
- Jira-Issue:OPENSTACK-545 (Steve Noyes)

* Fri Dec 04 2015 Borne Mace <borne.mace@oracle.com> - 0.1-120.el7
- host destroy will not not destroy data containers by default.  --includedata
  option added to destroy to remove all containers. (Borne Mace)

* Mon Nov 16 2015 Steve Noyes <steve.noyes@oracle.com> - 0.1-119.el7
- added code to remove spurious empty line generation from globals.yml (Borne Mace)  
- update property/password tests to check file size (Steve Noyes)

* Tue Nov 10 2015 Steve Noyes <steve.noyes@oracle.com> - 0.1-118.el7
- dump & log collector bug fixes (Steve Noyes)  
- removed fasteners from requirements file (Borne Mace)  
- update host check to remove obsolete usage of json generator. (Steve Noyes)  [Orabug: 22159340] 
- update host check to remove obsolete usage of json generator. (Steve Noyes)  [Orabug: 22159340] 
- removed useless info from changelog (add / remote fasteners) (Borne Mace)  
- removed fasteners usage and replaced with flock (Borne Mace)  
- remove redundant python-fasteners in spec file (Steve Noyes)  
- change fasteners to python-fasteners in spec file (Steve Noyes)  
- updated rpm build info with python-fasteners requirement (Borne Mace)  
- remove oslo-concurrency, add fasteners to build spec file. (Steve Noyes)  
- added pyc cleanup to tox test section (Borne Mace)  
- replace oslo.concurrency with fasteners for file locks (Oracle-Bug: 22117282) (Steve Noyes)  
- allow destroy test to run without hosts (Steve Noyes)  
- added simple tests for --serial and --groups deploy. added destroy --stop test. broke out dump test into a separate test. removed mysql from the list of test services, now we deploy only mysqlcluster. (Borne Mace)  
- update tox.ini to run utests (Steve Noyes)  
- remove obsolete json_generator (Steve Noyes)  
- added support for --stop argument on the destroy command (Borne Mace)  
- minor changes to the serial behavior based on review feedback (Borne Mace)  
- added support for the --serial flag on deploy for updates / upgrades (Borne Mace)  
- allow users to set a different log size (Steve Noyes)  
- fix typo in oslo.concurrency line (Steve Noyes)  
- oslo lock file and run_cmd output improvements - use oslo concurrency locking instead of lockfile for license reasons - normalize output on run_cmd logging (Steve Noyes)  
- finished testing new --services flag for deploy (Borne Mace)  
- further changes to support service tags and cache flushing (Borne Mace)  
- re-jigger return items on run_cmd so callers can better choose what to display after a command fails. (Steve Noyes)  
- testing tags and serial options (Borne Mace)  
- synchronize access to files to avoid corruption (Steve Noyes)  
- raise exception if password prompt encountered by run cmd (Steve Noyes)  
- fixes based on review feedback (Borne Mace)  
- unittest cleanup (Steve Noyes)  
- added support for selective deployment (Borne Mace)  
- change json generator to be a generated file (Steve Noyes)  
- fixed pep8 errors (Borne Mace)  
- added AnsiblePlaybook class and moved playbook calls out of common and host (Borne Mace)  
- change unittest test_config file from json to yml (Steve Noyes)  
- add ability to perform setup on multiple hosts (Steve Noyes)  
- update log collector to add kollacli dump output file (Steve Noyes)  
- add ability to inventory class to generate ansible json to specific groups or hosts (Steve Noyes)

* Wed Oct 07 2015 Steve Noyes <steve.noyes@oracle.com> - 0.1-117.el7
- fix bug 21960307 - when deleting a group, remove association from all
  services. (Steve Noyes)

* Wed Oct 07 2015 Borne Mace <borne.mace@oracle.com> - 0.1-116.el7
- changed error building methodology (Borne Mace)  
- added missing space in error message (Borne Mace)  
- Added separate failure message when the inventory.json file is missing (Borne Mace)

* Tue Oct 06 2015 Steve Noyes <steve.noyes@oracle.com> - 0.1-115.el7
- avoid adding redundant groups to service (Steve Noyes)  
- Allow copying the pub key even if the RPM did not create it (Wiekus Beukes)

* Thu Oct 01 2015 Steve Noyes <steve.noyes@oracle.com> - 0.1-114.el7
- add missing file attr for log_collector (Steve Noyes)  
- remove sudo from build spec (Steve Noyes)  
- add log_collector tool (Steve Noyes)  
- add quick check of dump command (Steve Noyes)  
- add new deploy and destroy tests (Steve Noyes)  
- update host test to avoid yum install/remove (Steve Noyes)  
- add script to run before checkins (Steve Noyes)

* Tue Sep 29 2015 Steve Noyes <steve.noyes@oracle.com> - 0.1-113.el7
- fix host setup cmd string issue (Steve Noyes)  
- update host test to support setup & check (Steve Noyes)

* Tue Sep 29 2015 Borne Mace <borne.mace@oracle.com> - 0.1-112.el7
- pep8 fixes (Borne Mace)  
- modified sudo to use the full path '/usr/bin/sudo'. updated permission denied message based on feedback. (Borne Mace)  
- changed permission check to verify against inventory file access rather than group membership, since root shouldn't need to be in the kolla group. (Borne Mace)  
- removed list command which was not being used / implemented. (Borne Mace)

* Fri Sep 25 2015 Steve Noyes <steve.noyes@oracle.com> - 0.1-111.el7
- add kolla group check to shell (Steve Noyes)

* Fri Sep 25 2015 Steve Noyes <steve.noyes@oracle.com> - 0.1-110.el7
- used sticky bits and acl to avoid rotational log override method (Steve Noyes)

* Fri Sep 25 2015 Steve Noyes <steve.noyes@oracle.com> - 0.1-19.el7
- 2nd fix for rotating log startup issue (Steve Noyes)

* Fri Sep 25 2015 Steve Noyes <steve.noyes@oracle.com> - 0.1-18.el7
- fix type in shell.py in log_rotate code (Steve Noyes)

* Fri Sep 25 2015 Borne Mace <borne.mace@oracle.com> - 0.1-17.el7
- changed stop to kill and fixed a bug that was introduced in the property clear logic that was found during testing. (Borne Mace)  
- modified destroy to use ansible environment variables to determine which containers to clean up. (Borne Mace)

* Thu Sep 24 2015 Steve Noyes <steve.noyes@oracle.com> - 0.1-16.el7
- fix bugs in last checkin in rpm spec (Steve Noyes)  
- create rotating log, add json and ansible-playbook output to dump (Steve Noyes)

* Wed Sep 23 2015 Borne Mace <borne.mace@oracle.com> - 0.1-15.el7
- changed log output and help syntax based on review feedback. (Borne Mace)  
- changed host destroy syntax to require param, if you want services on all hosts stopped the hostname 'all' must be given.  added a message to the command that the process might take a while. (Borne Mace)  
- add various cli list commands output to dump (Steve Noyes)  
- add swift deploy rule, improve command error (Steve Noyes)  
- completely remove mariadb from model & inventory (Steve Noyes)

* Mon Sep 21 2015 Steve Noyes <steve.noyes@oracle.com> - 0.1-14.el7
- clean up recent mariadb change to avoid an empty string in the list output (Steve Noyes)  
- added pre-command check for appropriate user permissions. (Borne Mace)  
- default mariadb to no group, fix bug in inventory children creation (Steve Noyes)  
- update to sub-services model (Steve Noyes)  
- moved kollacli stop to kollacli host destroy (Borne Mace)  
- fix group-service association bug (Steve Noyes)  
- fix some minor pep8 source formatting issues (Steve Noyes)  
- fix permission bug in dump, use more secure mkstemp (Steve Noyes)

* Mon Sep 21 2015 Borne Mace <borne.mace@oracle.com> - 0.1-13.el7
- Build it

* Thu Sep 17 2015 Borne Mace <borne.mace@oracle.com> - 0.1-12.el7
- made some minor changes suggested in the stop feature review. (Borne Mace)  
- added support for the stop command. added a new ansible directory to hold kollacli specific playbooks (Borne Mace)  
- update model to better match kolla's inventory model (Steve Noyes)

* Thu Sep 17 2015 Wiekus Beukes <wiekus.beukes@oracle.com> - 0.1-11.el7
- Added the bash completion setup Added code to augment the kolla sudo file for the password mgmt piece (Wiekus Beukes)  
- rename of mysql to mysqlcluster and other related changes. (Borne Mace)  
- add set/clear/list passwords cli commands (Steve Noyes)  
- add script to modify passwords file (Steve Noyes)  
- fix logging during deploy (Steve Noyes)

* Tue Sep 15 2015 Steve Noyes <steve.noyes@oracle.com> - 0.1-10.el7
- rearrange containers in swift and neutron (Steve Noyes)  
- create reserved group for all hosts (steve)  
- kolla is under openstack now rather than stackforge, fixed string (Borne Mace)

* Fri Sep 11 2015 Borne Mace <borne.mace@oracle.com> - 0.1-9.el7
- fixed tox error related to whitespace at the end of a line (Borne Mace)  
- fixed dump to work if the templates directory is missing. added host check back in before / after setup. (Borne Mace)  
- Summary: add template for doing upgrades to inventory (Steve Noyes)  
- Summary: drop use of str() on exception messages (Steve Noyes)  [Orabug: 21810245]

* Fri Sep 11 2015 Borne Mace <borne.mace@oracle.com> - 0.1-8.el7
- changed ndbcluster to mysql in inventory to match openstack-kolla changes. added murano service to match openstack-kolla changes (Borne Mace)  
- moved command execution code to utils. added support back in for the host check command. (Borne Mace)

* Thu Sep 10 2015 Borne Mace <borne.mace@oracle.com> - 0.1-7.el7
- set haproxy to be associated to the control group rather than network (Borne Mace)  
- Summary: normalize input strings to unicode (Steve Noyes)  [Orabug: 21810245]

* Wed Sep 09 2015 Borne Mace <borne.mace@oracle.com> - 0.1-6.el7
- added support for the dump command (Borne Mace)  
- fixed TODO comment format to match pep8 requirements (Borne Mace)  
- removed a lot of commented out code related to host check (Borne Mace)

* Tue Sep 08 2015 Wiekus Beukes <wiekus.beukes@oracle.com> - 0.1-5.el7
- Changed RPM build to only require pbr 1.3.0 (Wiekus Beukes)  
- Updated dependencies and changed config files to not get overwritten on RPM updates (Wiekus Beukes)  
- fixed pep8 errors (Borne Mace)  
- changed property output to return unique output and only keys / values (no more associated file name) (Borne Mace)

* Tue Sep 08 2015 Wiekus Beukes <wiekus.beukes@oracle.com> - 0.1-4.el7
- Prevent the inventory.json file to get overwritten on updates (Wiekus Beukes)

* Tue Sep 08 2015 Wiekus Beukes <wiekus.beukes@oracle.com> - 0.1-3.el7
- Add the creation of an empty inventory file so the permissions can be preset... (Wiekus Beukes)  
- Summary: support empty initialized inventory file (Steve Noyes)

* Fri Sep 04 2015 Wiekus Beukes <wiekus.beukes@oracle.com> - 0.1-2.el7
- Fixed the day of the week in the changelog (Wiekus Beukes)  
- Summary: split conder into control and data services (Steve Noyes)  
- Fixed all the post issues (Wiekus Beukes)

* Wed Sep 02 2015 - Wiekus Beukes <wiekus.beukes@oracle.com>
- Initial release

